@@ -2,7 +2,7 @@ from .dispatcher import grimoire
 
 
 def launcher():
-    grimoire(prog_name='servergrimoire')
+    grimoire(prog_name="servergrimoire")
 
 
 if __name__ == "__main__":
