@@ -1,5 +1,7 @@
 import json
 import os
+import errno
+import sys
 from pathlib import Path
 
 from loguru import logger
@@ -9,19 +11,29 @@ class ConfigManager:
     def __init__(self, path):
         self.config = {}
         if path is None:
-            path = Path.home() / ".servergrimoire_config"
-        self.path = path
+            self.path = Path.home() / ".servergrimoire/config"
+        else:
+            self.path = path
 
-        if not os.path.exists(path):
+        if not os.path.exists(self.path):
+            if not os.path.exists(os.path.dirname(self.path)):
+                try:
+                    os.makedirs(os.path.dirname(self.path))
+                except OSError as exc: # Guard against race condition
+                    if exc.errno != errno.EEXIST:
+                        raise
             self.__create_default__()
         else:
-            with open(path) as data_file:
+            with open(self.path) as data_file:
                 self.config = json.load(data_file)
         self.__preset__()
 
         self.__write_config__()
 
     def __preset__(self):
+        logger.remove()
+        logger.add(sys.stderr, level="ERROR")
+        logger.add(sys.stdout, level=self.logger_level)
         logger.debug(f"Data path {self.data_path}")
         self.config["data_path"] = f'{self.config["data_path"]}'
         logger.debug(f"Logger level is {self.logger_level}")
@@ -47,7 +59,7 @@ class ConfigManager:
     @data_path.getter
     def data_path(self):
         if self.config.get("data_path", None) is None:
-            self.config["data_path"] = Path.home() / ".servergrimoire_data"
+            self.config["data_path"] = Path.home() / ".servergrimoire/data"
         return self.config["data_path"]
 
     @property
